@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -33,19 +33,18 @@ ALL = (
 # General API
 #-----------------------------------------------------------------------------
 
-class Test_JSON(object):
 
+class Test_JSON:
     def test_valid(self) -> None:
         prop = bcpj.JSON()
 
-        assert prop.is_valid(None)
-
         assert prop.is_valid('[]')
         assert prop.is_valid('[{"foo": 10}]')
 
     def test_invalid(self) -> None:
         prop = bcpj.JSON()
 
+        assert not prop.is_valid(None)
         assert not prop.is_valid("")
         assert not prop.is_valid("foo")
         assert not prop.is_valid("[]]")
