@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -18,6 +18,7 @@ import pytest ; pytest
 from mock import patch
 
 # Bokeh imports
+from _util_property import _TestModel
 from bokeh._testing.util.api import verify_all
 from bokeh.core.properties import (
     Angle,
@@ -70,7 +71,7 @@ ALL = (
 
 def test_notify_owner() -> None:
     result = {}
-    class Foo(object):
+    class Foo:
         @bcpw.notify_owner
         def test(self): pass
 
@@ -89,7 +90,7 @@ def test_PropertyValueContainer() -> None:
     assert pvc._owners == set()
 
     pvc._register_owner("owner", "prop")
-    assert pvc._owners == set((("owner", "prop"), ))
+    assert pvc._owners == {("owner", "prop")}
 
     pvc._unregister_owner("owner", "prop")
     assert pvc._owners == set()
@@ -423,9 +424,14 @@ def test_PropertyValueColumnData___deepcopy__() -> None:
     assert source.data['foo'][0] == 10
 
 def test_Property_wrap() -> None:
-    for x in (Bool, Int, Float, Complex, String, Enum, Color,
-              Regex, Seq, Tuple, Instance, Any, Interval, Either,
-              DashPattern, Size, Percent, Angle, MinMaxBounds):
+    types = [
+        Bool(), Int(), Float(), Complex(), String(), Enum("Some", "a", "b"), Color(),
+        Regex("^$"), Seq(Any), Tuple(Any, Any), Instance(_TestModel), Any(),
+        Interval(Float, 0, 1), Either(Int, String), DashPattern(), Size(), Percent(),
+        Angle(), MinMaxBounds(),
+    ]
+
+    for x in types:
         for y in (0, 1, 2.3, "foo", None, (), [], {}):
             r = x.wrap(y)
             assert r == y
@@ -433,35 +439,35 @@ def test_Property_wrap() -> None:
 
 def test_List_wrap() -> None:
     for y in (0, 1, 2.3, "foo", None, (), {}):
-        r = List.wrap(y)
+        r = List(Any).wrap(y)
         assert r == y
         assert isinstance(r, type(y))
-    r = List.wrap([1,2,3])
+    r = List(Any).wrap([1,2,3])
     assert r == [1,2,3]
     assert isinstance(r, bcpw.PropertyValueList)
-    r2 = List.wrap(r)
+    r2 = List(Any).wrap(r)
     assert r is r2
 
 def test_Dict_wrap() -> None:
     for y in (0, 1, 2.3, "foo", None, (), []):
-        r = Dict.wrap(y)
+        r = Dict(Any, Any).wrap(y)
         assert r == y
         assert isinstance(r, type(y))
-    r = Dict.wrap(dict(a=1, b=2))
+    r = Dict(Any, Any).wrap(dict(a=1, b=2))
     assert r == dict(a=1, b=2)
     assert isinstance(r, bcpw.PropertyValueDict)
-    r2 = Dict.wrap(r)
+    r2 = Dict(Any, Any).wrap(r)
     assert r is r2
 
 def test_ColumnData_wrap() -> None:
     for y in (0, 1, 2.3, "foo", None, (), []):
-        r = ColumnData.wrap(y)
+        r = ColumnData(String, Any).wrap(y)
         assert r == y
         assert isinstance(r, type(y))
-    r = ColumnData.wrap(dict(a=1, b=2))
+    r = ColumnData(String, Any).wrap(dict(a=1, b=2))
     assert r == dict(a=1, b=2)
     assert isinstance(r, bcpw.PropertyValueColumnData)
-    r2 = ColumnData.wrap(r)
+    r2 = ColumnData(String, Any).wrap(r)
     assert r is r2
 
 #-----------------------------------------------------------------------------
